# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 1.0.3

([Full Changelog](https://github.com/bloomsa/launcher-links/compare/v1.0.2...b5fa648f501b7804e95acddb2b3407c5a4283f70))

### Enhancements made

- use setting order for rank on launcher. + cleanup [#9](https://github.com/bloomsa/launcher-links/pull/9) ([@bloomsa](https://github.com/bloomsa))

### Other merged PRs

- [skip ci] documentation updates [#7](https://github.com/bloomsa/launcher-links/pull/7) ([@bloomsa](https://github.com/bloomsa))
- docs: draft issues for remaining todo items [#3](https://github.com/bloomsa/launcher-links/pull/3) ([@bloomsa](https://github.com/bloomsa))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/bloomsa/launcher-links/graphs/contributors?from=2025-09-20&to=2025-11-08&type=c))

[@bloomsa](https://github.com/search?q=repo%3Abloomsa%2Flauncher-links+involves%3Abloomsa+updated%3A2025-09-20..2025-11-08&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Abloomsa%2Flauncher-links+involves%3Agithub-actions+updated%3A2025-09-20..2025-11-08&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 1.0.2

([Full Changelog](https://github.com/bloomsa/launcher-links/compare/772d45097cae9c490404286ad2ed2b76628ce703...e41d944bb409cc0c5cf95b743fd45df9d66b5261))

### Merged PRs

- linting fix and configure prettier [#2](https://github.com/bloomsa/launcher-links/pull/2) ([@bloomsa](https://github.com/bloomsa))
- initial release [#1](https://github.com/bloomsa/launcher-links/pull/1) ([@bloomsa](https://github.com/bloomsa))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/bloomsa/launcher-links/graphs/contributors?from=2025-03-24&to=2025-09-20&type=c))

[@bloomsa](https://github.com/search?q=repo%3Abloomsa%2Flauncher-links+involves%3Abloomsa+updated%3A2025-03-24..2025-09-20&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Abloomsa%2Flauncher-links+involves%3Agithub-actions+updated%3A2025-03-24..2025-09-20&type=Issues)

## 1.0.1

([Full Changelog](https://github.com/bloomsa/launcher-links/compare/772d45097cae9c490404286ad2ed2b76628ce703...e41d944bb409cc0c5cf95b743fd45df9d66b5261))

### Merged PRs

- linting fix and configure prettier [#2](https://github.com/bloomsa/launcher-links/pull/2) ([@bloomsa](https://github.com/bloomsa))
- initial release [#1](https://github.com/bloomsa/launcher-links/pull/1) ([@bloomsa](https://github.com/bloomsa))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/bloomsa/launcher-links/graphs/contributors?from=2025-03-24&to=2025-09-20&type=c))

[@bloomsa](https://github.com/search?q=repo%3Abloomsa%2Flauncher-links+involves%3Abloomsa+updated%3A2025-03-24..2025-09-20&type=Issues) | [@github-actions](https://github.com/search?q=repo%3Abloomsa%2Flauncher-links+involves%3Agithub-actions+updated%3A2025-03-24..2025-09-20&type=Issues)

## 1.0.0

First Release

### Features

- Add web link icons to the JupyterLab launcher and command palette.
  - Configurable Category
  - Support for svg icons
- Configurable with config file
